
;; set this to override the previously included BufferModeRb.conf.inc (in GeMAPS sets only) for the functionals
;; or (in all other sets), define the RbConf here to save memory on the functionals levels:
;writer.levelconf.growDyn = 0
;writer.levelconf.isRb = 1
;writer.levelconf.nT = 5

frameMode = full
frameSize = 0
frameStep = 0
frameCenterSpecial = left

